==> realestate-supervise-common-1.1.0-20250924.014108-69-sources.jar: cn/gtmap/realestate/supervise/entity/BaTdcbjyqfjLs.java <==
package cn.gtmap.realestate.supervise.entity;


import cn.gtmap.realestate.supervise.core.reflect.id;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;

/**
 * @author <a href="mailto:huming@gtmap.cn">huming</a>
 * @Date: 2023/12/29 9:07
 * @Description: 土地承包经营权登记信息（耕地等农用地）附记
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(
        name = "ba_tdcbjyqfj_ls"
)
public class BaTdcbjyqfjLs implements Serializable {

    @XmlAttribute
    @Id
    @id
    private String id;

    @XmlAttribute
    private String htdm;

    @XmlAttribute
    private String ycbhtmj;

    @XmlAttribute
    private String cbdqqhtzmj;

    @XmlAttribute
    private String cbdqqdkzs;

    @XmlAttribute
    private String cbdbdcdydm;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getHtdm() {
        return htdm;
    }

    public void setHtdm(String htdm) {
        this.htdm = htdm;
    }

    public String getYcbhtmj() {
        return ycbhtmj;
    }

    public void setYcbhtmj(String ycbhtmj) {
        this.ycbhtmj = ycbhtmj;
    }

    public String getCbdqqhtzmj() {
        return cbdqqhtzmj;
    }

    public void setCbdqqhtzmj(String cbdqqhtzmj) {
        this.cbdqqhtzmj = cbdqqhtzmj;
    }

    public String getCbdqqdkzs() {
        return cbdqqdkzs;
    }

    public void setCbdqqdkzs(String cbdqqdkzs) {
        this.cbdqqdkzs = cbdqqdkzs;
    }

    public String getCbdbdcdydm() {
        return cbdbdcdydm;
    }

    public void setCbdbdcdydm(String cbdbdcdydm) {
        this.cbdbdcdydm = cbdbdcdydm;
    }
}

==> realestate-supervise-common-1.1.0-20251204.031512-72-sources.jar: cn/gtmap/realestate/supervise/entity/BaTdcbjyqfjLs.java <==
package cn.gtmap.realestate.supervise.entity;


import cn.gtmap.realestate.supervise.core.reflect.id;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;

/**
 * @author <a href="mailto:huming@gtmap.cn">huming</a>
 * @Date: 2023/12/29 9:07
 * @Description: 土地承包经营权登记信息（耕地等农用地）附记
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(
        name = "ba_tdcbjyqfj_ls"
)
public class BaTdcbjyqfjLs implements Serializable {

    @XmlAttribute
    @Id
    @id
    private String id;

    @XmlAttribute
    private String htdm;

    @XmlAttribute
    private String ycbhtmj;

    @XmlAttribute
    private String cbdqqhtzmj;

    @XmlAttribute
    private String cbdqqdkzs;

    @XmlAttribute
    private String cbdbdcdydm;

    // ============73696 江苏省级_地籍数据监管模块总体需求新增字段开始===============

    /** 主要记载承包地块内容 */
    @XmlAttribute
    private String zyjzcbdknr;

    // ============73696 江苏省级_地籍数据监管模块总体需求新增字段结束===============

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getHtdm() {
        return htdm;
    }

    public void setHtdm(String htdm) {
        this.htdm = htdm;
    }

    public String getYcbhtmj() {
        return ycbhtmj;
    }

    public void setYcbhtmj(String ycbhtmj) {
        this.ycbhtmj = ycbhtmj;
    }

    public String getCbdqqhtzmj() {
        return cbdqqhtzmj;
    }

    public void setCbdqqhtzmj(String cbdqqhtzmj) {
        this.cbdqqhtzmj = cbdqqhtzmj;
    }

    public String getCbdqqdkzs() {
        return cbdqqdkzs;
    }

    public void setCbdqqdkzs(String cbdqqdkzs) {
        this.cbdqqdkzs = cbdqqdkzs;
    }

    public String getCbdbdcdydm() {
        return cbdbdcdydm;
    }

    public void setCbdbdcdydm(String cbdbdcdydm) {
        this.cbdbdcdydm = cbdbdcdydm;
    }

    public String getZyjzcbdknr() {
        return zyjzcbdknr;
    }

    public void setZyjzcbdknr(String zyjzcbdknr) {
        this.zyjzcbdknr = zyjzcbdknr;
    }
}
